@@ -21,18 +21,13 @@
 
 namespace kImageAnnotator {
 
-AbstractAnnotationItem::AbstractAnnotationItem(const PropertiesPtr &properties)
+AbstractAnnotationItem::AbstractAnnotationItem(const PropertiesPtr &properties):
+	mProperties(properties)
 {
-	Q_ASSERT(properties != nullptr);
-
-	updateProperties(properties);
-	mPainterPen.setCapStyle(Qt::RoundCap);
-	mPainterPen.setJoinStyle(Qt::RoundJoin);
-
 	mShape = new QPainterPath();
 	mStroker = new QPainterPathStroker(mPainterPen);
 
-	updateShadow();
+	Q_ASSERT(mProperties != nullptr);
 }
 
 AbstractAnnotationItem::AbstractAnnotationItem(const AbstractAnnotationItem &other)
@@ -41,10 +36,11 @@ AbstractAnnotationItem::AbstractAnnotationItem(const AbstractAnnotationItem &oth
 	mShape = new QPainterPath(*other.mShape);
 	mPainterPen = other.mPainterPen;
 	mStroker = new QPainterPathStroker(mPainterPen);
+
+
 	setZValue(other.zValue());
 	setCursor(other.cursor());
-
-	updateShadow();
+	setOpacity(other.opacity());
 }
 
 AbstractAnnotationItem::~AbstractAnnotationItem()
@@ -109,6 +105,7 @@ void AbstractAnnotationItem::paint(QPainter *painter, const QStyleOptionGraphics
 
 void AbstractAnnotationItem::adjustPainter(QPainter *painter) const
 {
+	painter->setCompositionMode(compositionMode());
 	painter->setRenderHint(QPainter::Antialiasing, true);
 	shiftPainterForAllOddShapeWidth(painter);
 }
@@ -118,6 +115,11 @@ QPen AbstractAnnotationItem::painterPen() const
 	return mPainterPen;
 }
 
+QPainter::CompositionMode AbstractAnnotationItem::compositionMode() const
+{
+	return QPainter::CompositionMode_Source;
+}
+
 void AbstractAnnotationItem::drawPoint(QPainter *painter) const
 {
 	painter->setPen(Qt::NoPen);
@@ -147,13 +149,18 @@ void AbstractAnnotationItem::drawPath(QPainter *painter) const
 	painter->drawPath(*mShape);
 }
 
-void AbstractAnnotationItem::updateProperties(const PropertiesPtr &properties)
+void AbstractAnnotationItem::updateProperties()
 {
-	mProperties = properties;
 	mPainterPen.setColor(mProperties->color());
 	mPainterPen.setWidth(mProperties->width());
+	mPainterPen.setCapStyle(Qt::RoundCap);
+	mPainterPen.setJoinStyle(Qt::RoundJoin);
+
+	setOpacity(mProperties->opacity());
 
 	updateShadow();
+
+	emit propertiesChanged();
 }
 
 void AbstractAnnotationItem::shiftPainterForAllOddShapeWidth(QPainter *painter) const
@@ -190,17 +197,22 @@ void AbstractAnnotationItem::setProperties(const PropertiesPtr &properties)
 	Q_ASSERT(properties != nullptr);
 
 	prepareGeometryChange();
-	updateProperties(properties);
+
+	mProperties = properties;
+	updateProperties();
+}
+
+void AbstractAnnotationItem::init()
+{
+	updateProperties();
 }
 
 void AbstractAnnotationItem::updateShadow()
 {
 	if (mProperties->shadowEnabled()) {
-		if(graphicsEffect() == nullptr) {
-			setGraphicsEffect(new ShadowEffect());
-		}
+		setGraphicsEffect(new ShadowEffect());
 	} else {
-		setGraphicsEffect(nullptr);
+		setGraphicsEffect(new NoEffect());
 	}
 }
 
