@@ -35,6 +35,8 @@ public:
 
 protected:
 	void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget) override;
+	QPainter::CompositionMode compositionMode() const override;
+	void updateShadow() override;
 };
 
 } // namespace kImageAnnotator
