@@ -27,11 +27,13 @@ AnnotationWidget::AnnotationWidget(Config *config) :
 	mGeneralSettings(new AnnotationGeneralSettings),
 	mToolSelection(new AnnotationToolSelection),
 	mImageSettings(new AnnotationImageSettings),
-	mSettingsAdapter(new AnnotationSettingsAdapter(mGeneralSettings, mItemSettings, mToolSelection, mImageSettings, config)),
-	mAnnotationTabWidget(new AnnotationTabWidget(config, mSettingsAdapter))
+	mControlsWidget(new AnnotationControlsWidget),
+	mSettingsAdapter(new AnnotationSettingsAdapter(mGeneralSettings, mItemSettings, mToolSelection, mImageSettings, mControlsWidget, config)),
+	mAnnotationTabWidget(new AnnotationTabWidget(config, mSettingsAdapter)),
+	mControlsDockWidget(nullptr)
 {
 	initGui();
-	restoreDockWidgets();
+	restoreDockWidgetsState();
 }
 
 AnnotationWidget::~AnnotationWidget()
@@ -40,6 +42,7 @@ AnnotationWidget::~AnnotationWidget()
 	delete mItemSettings;
 	delete mToolSelection;
 	delete mImageSettings;
+	delete mControlsWidget;
 	delete mGeneralSettings;
 }
 
@@ -66,14 +69,23 @@ void AnnotationWidget::initGui()
 	connect(mAnnotationTabWidget, &AnnotationTabWidget::tabMoved, this, &AnnotationWidget::tabMoved);
 	connect(mAnnotationTabWidget, &AnnotationTabWidget::tabContextMenuOpened, this, &AnnotationWidget::tabContextMenuOpened);
 
+	connect(mControlsWidget, &AnnotationControlsWidget::undo, mAnnotationTabWidget, &AnnotationTabWidget::undoTriggered);
+	connect(mControlsWidget, &AnnotationControlsWidget::redo, mAnnotationTabWidget, &AnnotationTabWidget::redoTriggered);
+	connect(mControlsWidget, &AnnotationControlsWidget::showScale, this, &AnnotationWidget::activateScale);
+	connect(mControlsWidget, &AnnotationControlsWidget::showCrop, this, &AnnotationWidget::activateCrop);
+	connect(mControlsWidget, &AnnotationControlsWidget::showRotate, this, &AnnotationWidget::activateRotate);
+	connect(mControlsWidget, &AnnotationControlsWidget::showModifyCanvas, this, &AnnotationWidget::activateModifyCanvas);
+	connect(mControlsWidget, &AnnotationControlsWidget::showCut, this, &AnnotationWidget::activateCut);
+
 	connect(qApp, &QCoreApplication::aboutToQuit, this, &AnnotationWidget::persistDockWidgets);
 }
 
-void AnnotationWidget::insertDockWidget(Qt::DockWidgetArea area, AbstractAnnotationDockWidgetContent *content)
+AnnotationDockWidget *AnnotationWidget::insertDockWidget(Qt::DockWidgetArea area, AbstractAnnotationDockWidgetContent *content)
 {
 	auto dockWidget = new AnnotationDockWidget(content);
 	mDockWidgets.append(dockWidget);
 	addDockWidget(area, dockWidget);
+	return dockWidget;
 }
 
 QImage AnnotationWidget::image() const
@@ -181,12 +193,24 @@ void AnnotationWidget::setSettingsCollapsed(bool isCollapsed)
 	}
 }
 
+void AnnotationWidget::setControlsWidgetVisible(bool enabled)
+{
+	if (enabled) {
+		if (mControlsDockWidget == nullptr) {
+			mControlsDockWidget = insertDockWidget(Qt::BottomDockWidgetArea, mControlsWidget);
+		}
+		restoreDockWidgetsState();
+	} else {
+		removeDockWidget(mControlsDockWidget);
+	}
+}
+
 void AnnotationWidget::persistDockWidgets()
 {
 	mConfig->setAnnotatorDockWidgetsState(saveState());
 }
 
-void AnnotationWidget::restoreDockWidgets()
+void AnnotationWidget::restoreDockWidgetsState()
 {
 	restoreState(mConfig->annotatorDockWidgetsState());
 }
