@@ -58,6 +58,7 @@ public:
 	void setStickers(const QStringList &stickerPaths, bool keepDefault);
 	void addTabContextMenuActions(const QList<QAction*> & actions);
 	void setSettingsCollapsed(bool isCollapsed);
+	void setControlsWidgetVisible(bool enabled);
 
 signals:
 	void imageChanged() const;
@@ -65,6 +66,11 @@ signals:
 	void tabCloseRequested(int index) const;
 	void tabMoved(int fromIndex, int toIndex);
 	void tabContextMenuOpened(int index) const;
+	void activateScale() const;
+	void activateCrop() const;
+	void activateRotate() const;
+	void activateModifyCanvas() const;
+	void activateCut() const;
 
 private:
 	Config *mConfig;
@@ -72,16 +78,18 @@ private:
 	AnnotationGeneralSettings *mGeneralSettings;
 	AnnotationToolSelection *mToolSelection;
 	AnnotationImageSettings *mImageSettings;
+	AnnotationControlsWidget *mControlsWidget;
 	AnnotationSettingsAdapter *mSettingsAdapter;
 	AnnotationTabWidget *mAnnotationTabWidget;
 	QList<AnnotationDockWidget*> mDockWidgets;
+	AnnotationDockWidget *mControlsDockWidget;
 
 	void initGui();
-	void insertDockWidget(Qt::DockWidgetArea area, AbstractAnnotationDockWidgetContent *content);
+	AnnotationDockWidget *insertDockWidget(Qt::DockWidgetArea area, AbstractAnnotationDockWidgetContent *content);
 
 private slots:
 	void persistDockWidgets();
-	void restoreDockWidgets();
+	void restoreDockWidgetsState();
 };
 
 } // namespace kImageAnnotator
