@@ -45,30 +45,48 @@
     </message>
 </context>
 <context>
-    <name>kImageAnnotator::AnnotationSettings</name>
+    <name>kImageAnnotator::AnnotationGeneralSettings</name>
+    <message>
+        <source>General Settings</source>
+        <translation>Общие настройки</translation>
+    </message>
+</context>
+<context>
+    <name>kImageAnnotator::AnnotationImageSettings</name>
+    <message>
+        <source>Image Settings</source>
+        <translation>Настройки изображения</translation>
+    </message>
+</context>
+<context>
+    <name>kImageAnnotator::AnnotationItemSettings</name>
     <message>
         <source>Color</source>
         <translation>Цвет</translation>
     </message>
-    <message>
-        <source>Width</source>
-        <translation>Ширина</translation>
-    </message>
     <message>
         <source>Text Color</source>
         <translation>Цвет текста</translation>
     </message>
     <message>
-        <source>Font Size</source>
-        <translation>Размер шрифта</translation>
+        <source>Width</source>
+        <translation>Ширина</translation>
     </message>
     <message>
-        <source>Starting Number</source>
-        <translation>Начальный номер</translation>
+        <source>Number Seed</source>
+        <translation>Нумератор</translation>
     </message>
     <message>
         <source>Obfuscation Factor</source>
-        <translation type="unfinished"></translation>
+        <translation>Уровень обфускации</translation>
+    </message>
+    <message>
+        <source>Item Shadow</source>
+        <translation>Тень элемента</translation>
+    </message>
+    <message>
+        <source>Item Settings</source>
+        <translation>Настройки элемента</translation>
     </message>
 </context>
 <context>
@@ -95,11 +113,25 @@
     </message>
 </context>
 <context>
-    <name>kImageAnnotator::CropWidget</name>
+    <name>kImageAnnotator::AnnotationToolSelection</name>
     <message>
-        <source>Crop</source>
-        <translation>Обрезать</translation>
+        <source>Tool Selection</source>
+        <translation>Выбор инструмента</translation>
     </message>
+</context>
+<context>
+    <name>kImageAnnotator::BoolPicker</name>
+    <message>
+        <source>Enabled</source>
+        <translation>Включено</translation>
+    </message>
+    <message>
+        <source>Disabled</source>
+        <translation>Отключено</translation>
+    </message>
+</context>
+<context>
+    <name>kImageAnnotator::CropWidget</name>
     <message>
         <source>Cancel</source>
         <translation>Отмена</translation>
@@ -120,47 +152,172 @@
         <source>H:</source>
         <translation>В:</translation>
     </message>
+    <message>
+        <source>Apply</source>
+        <translation>Применить</translation>
+    </message>
 </context>
 <context>
     <name>kImageAnnotator::FillModePicker</name>
     <message>
         <source>Border And Fill Visibility</source>
-        <translation type="unfinished">Видимость обводки и заливки</translation>
+        <translation>Видимость обводки и заливки</translation>
     </message>
     <message>
         <source>Border and Fill</source>
-        <translation type="unfinished">Обводка и заливка</translation>
+        <translation>Обводка и заливка</translation>
     </message>
     <message>
         <source>Border and No Fill</source>
-        <translation type="unfinished">Обводка без заливки</translation>
+        <translation>Обводка без заливки</translation>
     </message>
     <message>
         <source>No Border and No Fill</source>
-        <translation type="unfinished">Без обводки и заливки</translation>
+        <translation>Без обводки и заливки</translation>
+    </message>
+</context>
+<context>
+    <name>kImageAnnotator::FontPicker</name>
+    <message>
+        <source>Font Size</source>
+        <translation>Размер шрифта</translation>
+    </message>
+    <message>
+        <source>Bold</source>
+        <translation>Жирный</translation>
+    </message>
+    <message>
+        <source>Italic</source>
+        <translation>Курсив</translation>
+    </message>
+    <message>
+        <source>Underline</source>
+        <translation>Подчёркнутый</translation>
     </message>
 </context>
 <context>
     <name>kImageAnnotator::ImageEffectPicker</name>
     <message>
         <source>Image Effects</source>
-        <translation type="unfinished"></translation>
+        <translation>Графические эффекты</translation>
     </message>
     <message>
         <source>No Effect</source>
-        <translation type="unfinished"></translation>
+        <translation>Без эффекта</translation>
     </message>
     <message>
         <source>Drop Shadow</source>
-        <translation type="unfinished"></translation>
+        <translation>Отбросить тень</translation>
     </message>
     <message>
         <source>Grayscale</source>
-        <translation type="unfinished"></translation>
+        <translation>Оттенки серого</translation>
     </message>
     <message>
         <source>Border</source>
-        <translation type="unfinished"></translation>
+        <translation>Рамка</translation>
+    </message>
+    <message>
+        <source>Invert Color</source>
+        <translation>Инвертировать цвет</translation>
+    </message>
+</context>
+<context>
+    <name>kImageAnnotator::ModifyCanvasWidget</name>
+    <message>
+        <source>Restricted</source>
+        <translation>Ограничено</translation>
+    </message>
+    <message>
+        <source>When enabled enforces the canvas
+to include the background image.</source>
+        <translation>Включить принудительный захват
+фонового изображения.</translation>
+    </message>
+    <message>
+        <source>X:</source>
+        <translation>X:</translation>
+    </message>
+    <message>
+        <source>Y:</source>
+        <translation>Y:</translation>
+    </message>
+    <message>
+        <source>W:</source>
+        <translation>Ширина:</translation>
+    </message>
+    <message>
+        <source>H:</source>
+        <translation>Высота:</translation>
+    </message>
+    <message>
+        <source>Apply</source>
+        <translation>Применить</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Отменить</translation>
+    </message>
+    <message>
+        <source>Color:</source>
+        <translation>Цвет:</translation>
+    </message>
+    <message>
+        <source>Canvas Background Color</source>
+        <translation>Цвет фона</translation>
+    </message>
+</context>
+<context>
+    <name>kImageAnnotator::RotateDialog</name>
+    <message>
+        <source>Rotate Image</source>
+        <translation>Повернуть изображение</translation>
+    </message>
+    <message>
+        <source>180°</source>
+        <translation>180°</translation>
+    </message>
+    <message>
+        <source>90° Clockwise</source>
+        <translation>90° по часовой стрелке</translation>
+    </message>
+    <message>
+        <source>90° Counter Clockwise</source>
+        <translation>90° против часовой стрелки</translation>
+    </message>
+    <message>
+        <source>Arbitrary</source>
+        <translation>Задать угол</translation>
+    </message>
+    <message>
+        <source>Positive values rotate clockwise, negative values counter clockwise.
+Rotating by non 90° multipliers might introduce loss of quality.</source>
+        <translation>Положительные значения — по часовой стрелке, отрицательные — против.
+Поворот на некратный 90° угол может привести к потере качества.</translation>
+    </message>
+    <message>
+        <source>Horizontal</source>
+        <translation>Горизонально</translation>
+    </message>
+    <message>
+        <source>Vertical</source>
+        <translation>Вертикально</translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation>Применить</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Отменить</translation>
+    </message>
+    <message>
+        <source>Rotate</source>
+        <translation>Повернуть</translation>
+    </message>
+    <message>
+        <source>Flip</source>
+        <translation>Отразить</translation>
     </message>
 </context>
 <context>
@@ -202,7 +359,7 @@
     <name>kImageAnnotator::StickerPicker</name>
     <message>
         <source>Sticker</source>
-        <translation type="unfinished">Стикер</translation>
+        <translation>Стикер</translation>
     </message>
 </context>
 <context>
@@ -269,26 +426,38 @@
     </message>
     <message>
         <source>Pixelate</source>
-        <translation type="unfinished"></translation>
+        <translation>Пикселизовать</translation>
     </message>
     <message>
         <source>Text Pointer</source>
-        <translation type="unfinished"></translation>
+        <translation>Текстовый указатель</translation>
     </message>
     <message>
         <source>Text Arrow</source>
-        <translation type="unfinished"></translation>
+        <translation>Стрелка с текстом</translation>
     </message>
     <message>
         <source>Number Arrow</source>
-        <translation type="unfinished"></translation>
+        <translation>Стрелка с цифрой</translation>
+    </message>
+    <message>
+        <source>Duplicate</source>
+        <translation>Дублировать</translation>
     </message>
 </context>
 <context>
-    <name>kImageAnnotator::ZoomIndicator</name>
+    <name>kImageAnnotator::ZoomPicker</name>
     <message>
-        <source>Zoom Level</source>
-        <translation type="unfinished"></translation>
+        <source>Zoom In (%1)</source>
+        <translation>Увеличить (%1)</translation>
+    </message>
+    <message>
+        <source>Zoom Out (%1)</source>
+        <translation>Уменьшить (%1)</translation>
+    </message>
+    <message>
+        <source>Reset Zoom (%1)</source>
+        <translation>Исходный масштаб (%1)</translation>
     </message>
 </context>
 </TS>
