@@ -45,31 +45,49 @@
     </message>
 </context>
 <context>
-    <name>kImageAnnotator::AnnotationSettings</name>
+    <name>kImageAnnotator::AnnotationGeneralSettings</name>
+    <message>
+        <source>General Settings</source>
+        <translation>Allmänna Inställningar</translation>
+    </message>
+</context>
+<context>
+    <name>kImageAnnotator::AnnotationImageSettings</name>
+    <message>
+        <source>Image Settings</source>
+        <translation>Bildinställningar</translation>
+    </message>
+</context>
+<context>
+    <name>kImageAnnotator::AnnotationItemSettings</name>
     <message>
         <source>Color</source>
         <translation>Färg</translation>
     </message>
-    <message>
-        <source>Width</source>
-        <translation>Bredd</translation>
-    </message>
     <message>
         <source>Text Color</source>
         <translation>Textfärg</translation>
     </message>
     <message>
-        <source>Font Size</source>
-        <translation>Teckenstorlek</translation>
+        <source>Width</source>
+        <translation>Bredd</translation>
     </message>
     <message>
-        <source>Starting Number</source>
-        <translation>Startnummer</translation>
+        <source>Number Seed</source>
+        <translation>Räkneverk</translation>
     </message>
     <message>
         <source>Obfuscation Factor</source>
         <translation>Fördunklingsfaktor</translation>
     </message>
+    <message>
+        <source>Item Shadow</source>
+        <translation>Objektskugga</translation>
+    </message>
+    <message>
+        <source>Item Settings</source>
+        <translation>Objektinställningar</translation>
+    </message>
 </context>
 <context>
     <name>kImageAnnotator::AnnotationTabContextMenu</name>
@@ -95,11 +113,25 @@
     </message>
 </context>
 <context>
-    <name>kImageAnnotator::CropWidget</name>
+    <name>kImageAnnotator::AnnotationToolSelection</name>
     <message>
-        <source>Crop</source>
-        <translation>Beskär</translation>
+        <source>Tool Selection</source>
+        <translation>Verktygsval</translation>
     </message>
+</context>
+<context>
+    <name>kImageAnnotator::BoolPicker</name>
+    <message>
+        <source>Enabled</source>
+        <translation>Aktiverat</translation>
+    </message>
+    <message>
+        <source>Disabled</source>
+        <translation>Inaktiverat</translation>
+    </message>
+</context>
+<context>
+    <name>kImageAnnotator::CropWidget</name>
     <message>
         <source>Cancel</source>
         <translation>Avbryt</translation>
@@ -120,6 +152,10 @@
         <source>H:</source>
         <translation>H:</translation>
     </message>
+    <message>
+        <source>Apply</source>
+        <translation>Tillämpa</translation>
+    </message>
 </context>
 <context>
     <name>kImageAnnotator::FillModePicker</name>
@@ -140,6 +176,25 @@
         <translation>Ingen kantlinje och ingen fyllning</translation>
     </message>
 </context>
+<context>
+    <name>kImageAnnotator::FontPicker</name>
+    <message>
+        <source>Font Size</source>
+        <translation>Teckenstorlek</translation>
+    </message>
+    <message>
+        <source>Bold</source>
+        <translation>Fet</translation>
+    </message>
+    <message>
+        <source>Italic</source>
+        <translation>Kursiv</translation>
+    </message>
+    <message>
+        <source>Underline</source>
+        <translation>Understruken</translation>
+    </message>
+</context>
 <context>
     <name>kImageAnnotator::ImageEffectPicker</name>
     <message>
@@ -162,6 +217,108 @@
         <source>Border</source>
         <translation>Kantlinje</translation>
     </message>
+    <message>
+        <source>Invert Color</source>
+        <translation>Invertera färg</translation>
+    </message>
+</context>
+<context>
+    <name>kImageAnnotator::ModifyCanvasWidget</name>
+    <message>
+        <source>Restricted</source>
+        <translation>Begränsad</translation>
+    </message>
+    <message>
+        <source>When enabled enforces the canvas
+to include the background image.</source>
+        <translation>Vid aktivering tvingas arbetsytan
+att inkludera bakgrundsbilden.</translation>
+    </message>
+    <message>
+        <source>X:</source>
+        <translation>X:</translation>
+    </message>
+    <message>
+        <source>Y:</source>
+        <translation>Y:</translation>
+    </message>
+    <message>
+        <source>W:</source>
+        <translation>B:</translation>
+    </message>
+    <message>
+        <source>H:</source>
+        <translation>H:</translation>
+    </message>
+    <message>
+        <source>Apply</source>
+        <translation>Tillämpa</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Avbryt</translation>
+    </message>
+    <message>
+        <source>Color:</source>
+        <translation>Färg:</translation>
+    </message>
+    <message>
+        <source>Canvas Background Color</source>
+        <translation>Arbetsytans bakgrundsfärg</translation>
+    </message>
+</context>
+<context>
+    <name>kImageAnnotator::RotateDialog</name>
+    <message>
+        <source>Rotate Image</source>
+        <translation>Rotera bilden</translation>
+    </message>
+    <message>
+        <source>180°</source>
+        <translation>180°</translation>
+    </message>
+    <message>
+        <source>90° Clockwise</source>
+        <translation>90° medurs</translation>
+    </message>
+    <message>
+        <source>90° Counter Clockwise</source>
+        <translation>90° moturs</translation>
+    </message>
+    <message>
+        <source>Arbitrary</source>
+        <translation>Slumpmässig</translation>
+    </message>
+    <message>
+        <source>Positive values rotate clockwise, negative values counter clockwise.
+Rotating by non 90° multipliers might introduce loss of quality.</source>
+        <translation>Positiva värden roterar medurs, negativa värden moturs.
+Rotation med annat än 90°-multiplikator kan leda till kvalitetsförlust.</translation>
+    </message>
+    <message>
+        <source>Horizontal</source>
+        <translation>Horisontellt</translation>
+    </message>
+    <message>
+        <source>Vertical</source>
+        <translation>Vertikalt</translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation>OK</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Avbryt</translation>
+    </message>
+    <message>
+        <source>Rotate</source>
+        <translation>Rotera</translation>
+    </message>
+    <message>
+        <source>Flip</source>
+        <translation>Vänd</translation>
+    </message>
 </context>
 <context>
     <name>kImageAnnotator::ScaleDialog</name>
@@ -283,12 +440,24 @@
         <source>Number Arrow</source>
         <translation>Sifferpil</translation>
     </message>
+    <message>
+        <source>Duplicate</source>
+        <translation>Duplicera</translation>
+    </message>
 </context>
 <context>
-    <name>kImageAnnotator::ZoomIndicator</name>
+    <name>kImageAnnotator::ZoomPicker</name>
     <message>
-        <source>Zoom Level</source>
-        <translation>Zoomnivå</translation>
+        <source>Zoom In (%1)</source>
+        <translation>Zooma in (%1)</translation>
+    </message>
+    <message>
+        <source>Zoom Out (%1)</source>
+        <translation>Zooma ut (%1)</translation>
+    </message>
+    <message>
+        <source>Reset Zoom (%1)</source>
+        <translation>Återställ zoom (%1)</translation>
     </message>
 </context>
 </TS>
